@@ -29,18 +29,29 @@ class NavigationEventsTransformers(CaliperTransformer):
         Returns:
             dict
         """
+        self.event_version = "1.0"
+        self.backend_name = 'caliper'
         caliper_object = self.transformed_event['object']
-        data = self.event['data'].copy()
 
-        object_id = data.pop('target_url') if self.event['name'] in (
+        data = self.get_data('data')
+        if self.get_data('name', True) in (
             'edx.ui.lms.link_clicked',
             'edx.ui.lms.outline.selected'
-        ) else data.pop('id')
+        ):
+            object_id = self.get_data('data.target_url', True)
+        else:
+            object_id = self.get_data('data.id', True)
+            data.pop('id')
 
         caliper_object.update({
             'id': object_id,
             'type': 'WebPage',
-            'extensions': data
         })
 
+        caliper_object.pop('extensions', None)
+
+        extensions = self.extract_subdict_by_keys(data, ['current_tab', 'tab_count', 'target_tab', 'widget_placement'])
+        if extensions:
+            caliper_object.update({'extensions': extensions})
+
         return caliper_object
