@@ -63,7 +63,7 @@ class BaseVideoTransformer(CaliperTransformer):
         Returns:
             str
         """
-        return EVENTS_ACTION_MAP[self.event['name']]
+        return EVENTS_ACTION_MAP[self.get_data('name', True)]
 
     def get_object(self):
         """
@@ -72,20 +72,33 @@ class BaseVideoTransformer(CaliperTransformer):
         Returns:
             str
         """
+        self.event_version = "1.0"
+        self.backend_name = 'caliper'
         caliper_object = self.transformed_event['object']
-        event = self.event['data'].copy()
-        course_id = self.find_nested('course_id')
-        video_id = event['id']
-
+        data = self.get_data('data')
+        course_id = self.get_data('context.course_id', True)
+        video_id = self.get_data('data.id', True)
         object_id = make_video_block_id(course_id=course_id, video_id=video_id)
 
         caliper_object.update({
             'id': object_id,
             'type': 'VideoObject',
             'duration': duration_isoformat(timedelta(
-                    seconds=event.pop('duration')
+                    seconds=data.get('duration', 0)
             ))
         })
+        caliper_object['extensions'] = {'course_id': course_id}
+        extensions = self.extract_subdict_by_keys(
+            data, ['id', 'new_time', 'old_time', 'currentTime']
+        )
+
+        if 'currentTime' in extensions:
+            extensions['currentTime'] = convert_seconds_to_iso(extensions['currentTime'])
+        if 'new_time' in extensions:
+            extensions['new_time'] = convert_seconds_to_iso(seconds=extensions['new_time'])
+        if 'old_time' in extensions:
+            extensions['old_time'] = convert_seconds_to_iso(seconds=extensions['old_time'])
+        caliper_object['extensions'].update(extensions)
 
         return caliper_object
 
@@ -98,18 +111,6 @@ class LoadVideoTransformer(BaseVideoTransformer):
     """
     type = 'Event'
 
-    def get_object(self):
-        """
-        Return transformed object for the caliper event.
-
-        Returns:
-            dict
-        """
-        caliper_object = super().get_object()
-
-        caliper_object['extensions'].update(self.event['data'])
-        return caliper_object
-
 
 @CaliperTransformersRegistry.register('stop_video')
 @CaliperTransformersRegistry.register('edx.video.stopped')
@@ -123,22 +124,6 @@ class StopVideoTransformer(BaseVideoTransformer):
     expected to be added.
     """
 
-    def get_object(self):
-        """
-        Return transformed object for the caliper event.
-
-        Returns:
-            dict
-        """
-        caliper_object = super().get_object()
-        data = self.event['data'].copy()
-
-        if 'currentTime' in data:
-            caliper_object['extensions']['currentTime'] = convert_seconds_to_iso(data.pop('currentTime'))
-
-        caliper_object['extensions'].update(data)
-        return caliper_object
-
 
 @CaliperTransformersRegistry.register('play_video')
 @CaliperTransformersRegistry.register('edx.video.played')
@@ -159,13 +144,10 @@ class PlayPauseVideoTransformer(BaseVideoTransformer):
         """
         caliper_object = super().get_object()
 
-        data = self.event['data'].copy()
-
         # currentTime is included in the `target` of transformed event
         # therefore no need to include it in the `extensions`.
-        data.pop('currentTime', None)
+        caliper_object['extensions'].pop('currentTime', None)
 
-        caliper_object['extensions'].update(data)
         return caliper_object
 
     def get_target(self):
@@ -176,7 +158,7 @@ class PlayPauseVideoTransformer(BaseVideoTransformer):
             str
         """
         current_time = convert_seconds_to_iso(
-            seconds=self.event['data']['currentTime']
+            seconds=self.get_data('data.currentTime')
         )
 
         return {
@@ -192,27 +174,3 @@ class SeekVideoTransformer(BaseVideoTransformer):
     """
     Transform the events fired when a video is seeked.
     """
-
-    def get_object(self):
-        """
-        Return tranformed object for the caliper event.
-
-        Returns:
-            dict
-        """
-        caliper_object = super().get_object()
-        data = self.event['data'].copy()
-
-        new_time = convert_seconds_to_iso(
-            seconds=data.pop('new_time')
-        )
-        old_time = convert_seconds_to_iso(
-            seconds=data.pop('old_time')
-        )
-        caliper_object['extensions'].update({
-            'new_time': new_time,
-            'old_time': old_time
-        })
-
-        caliper_object['extensions'].update(data)
-        return caliper_object
