@@ -2,13 +2,11 @@
 Test the transformers for all of the currently supported events into Caliper format.
 """
 import os
-from unittest.mock import patch
 
 from django.test import TestCase
 
 from event_routing_backends.processors.caliper.registry import CaliperTransformersRegistry
 from event_routing_backends.processors.tests.transformers_test_mixin import TransformersTestMixin
-from test_utils import mocked_course_reverse
 
 
 class TestCaliperTransformers(TransformersTestMixin, TestCase):
@@ -19,15 +17,6 @@ class TestCaliperTransformers(TransformersTestMixin, TestCase):
 
     registry = CaliperTransformersRegistry
 
-    def setUp(self):
-        super().setUp()
-        self.mocked_reverse = patch(
-            'event_routing_backends.helpers.reverse',
-            side_effect=mocked_course_reverse
-        )
-        self.mocked_reverse.start()
-        self.addCleanup(self.mocked_reverse.stop)
-
     def compare_events(self, transformed_event, expected_event):
         """
         Test that transformed_event and expected_event are identical.
