@@ -2,9 +2,9 @@
 Transformers for enrollment related events.
 """
 
-from tincan import Activity, ActivityDefinition, Context, LanguageMap, Verb
+from tincan import Activity, ActivityDefinition, Extensions, LanguageMap, Verb
 
-from event_routing_backends.helpers import get_anonymous_user_id, get_course_from_id, make_course_url
+from event_routing_backends.helpers import get_course_from_id
 from event_routing_backends.processors.xapi import constants
 from event_routing_backends.processors.xapi.registry import XApiTransformersRegistry
 from event_routing_backends.processors.xapi.transformer import XApiTransformer
@@ -14,7 +14,7 @@ class BaseEnrollmentTransformer(XApiTransformer):
     """
     Base transformer for enrollment events.
     """
-    additional_fields = ('context', )
+    additional_fields = ()
     event_version = 1.0
 
     def get_object(self):
@@ -25,7 +25,7 @@ class BaseEnrollmentTransformer(XApiTransformer):
             `Activity`
         """
         course_id = self.get_data('context.course_id', True)
-        object_id = make_course_url(course_id)
+        object_id = self.get_object_iri('course', course_id)
         course = get_course_from_id(course_id)
         display_name = course['display_name']
 
@@ -34,24 +34,12 @@ class BaseEnrollmentTransformer(XApiTransformer):
             definition=ActivityDefinition(
                 type=constants.XAPI_ACTIVITY_COURSE,
                 name=LanguageMap(**({constants.EN: display_name} if display_name is not None else {})),
+                extensions=Extensions({
+                    constants.XAPI_ACTIVITY_MODE: self.get_data('data.mode')
+                })
             ),
         )
 
-    def get_context(self):
-        """
-        Get context for xAPI transformed event.
-
-        Returns:
-            `Context`
-        """
-
-        context = Context(
-            registration=get_anonymous_user_id(
-                self.extract_username_or_userid()
-            )
-        )
-        return context
-
 
 @XApiTransformersRegistry.register('edx.course.enrollment.activated')
 class EnrollmentActivatedTransformer(BaseEnrollmentTransformer):
@@ -81,6 +69,6 @@ class CourseGradePassedFirstTimeTransformer(BaseEnrollmentTransformer):
     Transformers for event generated when learner pass course grade first time from a course.
     """
     verb = Verb(
-        id=constants.XAPI_VERB_COMPLETED,
-        display=LanguageMap({constants.EN: constants.COMPLETED}),
+        id=constants.XAPI_VERB_PASSED,
+        display=LanguageMap({constants.EN: constants.PASSED}),
     )
