@@ -1,37 +1,36 @@
 """
 Transformers for navigation related events.
 """
-from tincan import Activity, ActivityDefinition, ActivityList, Context, ContextActivities, Extensions, LanguageMap
+from tincan import Activity, ActivityDefinition, Context, Extensions, LanguageMap
 
-from event_routing_backends.helpers import get_anonymous_user_id, make_course_url
 from event_routing_backends.processors.xapi import constants
 from event_routing_backends.processors.xapi.registry import XApiTransformersRegistry
 from event_routing_backends.processors.xapi.transformer import XApiTransformer, XApiVerbTransformerMixin
 
 VERB_MAP = {
     'edx.ui.lms.sequence.next_selected': {
-        'id': constants.XAPI_VERB_TERMINATED,
-        'display': constants.TERMINATED
+        'id': constants.XAPI_VERB_NAVIGATED,
+        'display': constants.NAVIGATED
     },
     'edx.ui.lms.sequence.previous_selected': {
-        'id': constants.XAPI_VERB_TERMINATED,
-        'display': constants.TERMINATED
+        'id': constants.XAPI_VERB_NAVIGATED,
+        'display': constants.NAVIGATED
     },
     'edx.ui.lms.sequence.tab_selected': {
-        'id': constants.XAPI_VERB_INITIALIZED,
-        'display': constants.INITIALIZED
+        'id': constants.XAPI_VERB_NAVIGATED,
+        'display': constants.NAVIGATED
     },
     'edx.ui.lms.link_clicked': {
-        'id': constants.XAPI_VERB_EXPERIENCED,
-        'display': constants.EXPERIENCED
+        'id': constants.XAPI_VERB_NAVIGATED,
+        'display': constants.NAVIGATED
     },
     'edx.ui.lms.sequence.outline.selected': {
-        'id': constants.XAPI_VERB_INITIALIZED,
-        'display': constants.INITIALIZED
+        'id': constants.XAPI_VERB_NAVIGATED,
+        'display': constants.NAVIGATED
     },
     'edx.ui.lms.outline.selected': {
-        'id': constants.XAPI_VERB_INITIALIZED,
-        'display': constants.INITIALIZED
+        'id': constants.XAPI_VERB_NAVIGATED,
+        'display': constants.NAVIGATED
     }
 }
 
@@ -61,13 +60,9 @@ class LinkClickedTransformer(NavigationTransformersMixin):
             `Activity`
         """
         return Activity(
-            id=self.get_data('data.target_url', True),
+            id=self.get_data('data.target_url'),
             definition=ActivityDefinition(
-                type=constants.XAPI_ACTIVITY_LINK,
-                name=LanguageMap({constants.EN: 'Link name'}),
-                extensions=Extensions({
-                    constants.XAPI_ACTIVITY_POSITION: self.get_data('data.target_url')
-                })
+                type=constants.XAPI_ACTIVITY_LINK
             ),
         )
 
@@ -80,30 +75,10 @@ class LinkClickedTransformer(NavigationTransformersMixin):
         """
 
         context = Context(
-            registration=get_anonymous_user_id(
-                self.extract_username_or_userid()
-            ),
             contextActivities=self.get_context_activities()
         )
         return context
 
-    def get_context_activities(self):
-        """
-        Get context activities for xAPI transformed event.
-
-        Returns:
-            `ContextActivities`
-        """
-        parent_activities = [
-            Activity(
-                id=make_course_url(self.get_data('context.course_id')),
-                object_type=constants.XAPI_ACTIVITY_COURSE
-            ),
-        ]
-        return ContextActivities(
-            parent=ActivityList(parent_activities),
-        )
-
 
 @ XApiTransformersRegistry.register('edx.ui.lms.sequence.outline.selected')
 @ XApiTransformersRegistry.register('edx.ui.lms.outline.selected')
@@ -124,7 +99,7 @@ class OutlineSelectedTransformer(NavigationTransformersMixin):
             id=self.get_data('data.target_url'),
             definition=ActivityDefinition(
                 type=constants.XAPI_ACTIVITY_MODULE,
-                name=LanguageMap({constants.EN: self.get_data('data.target_name')}),
+                name=LanguageMap({constants.EN: self.get_data('data.target_name')})
             ),
         )
 
@@ -136,9 +111,7 @@ class OutlineSelectedTransformer(NavigationTransformersMixin):
             `Context`
         """
         context = Context(
-            registration=get_anonymous_user_id(
-                self.extract_username_or_userid()
-            )
+            contextActivities=self.get_context_activities()
         )
         return context
 
@@ -159,17 +132,12 @@ class TabNavigationTransformer(NavigationTransformersMixin):
         Returns:
             `Activity`
         """
-        if self.get_data('name', True) == 'edx.ui.lms.sequence.tab_selected':
-            position = self.get_data('data.target_tab')
-        else:
-            position = self.get_data('data.current_tab')
-
         return Activity(
-            id=self.get_data('data.id'),
+            id=self.get_object_iri('xblock', self.get_data('data.id')),
             definition=ActivityDefinition(
-                type=constants.XAPI_ACTIVITY_MODULE,
+                type=constants.XAPI_ACTIVITY_RESOURCE,
                 extensions=Extensions({
-                    constants.XAPI_ACTIVITY_POSITION: position
+                    constants.XAPI_ACTIVITY_TOTAL_COUNT: self.get_data('data.tab_count')
                 })
             ),
         )
@@ -185,38 +153,21 @@ class TabNavigationTransformer(NavigationTransformersMixin):
         if event_name == 'edx.ui.lms.sequence.tab_selected':
             extensions = Extensions({
                 constants.XAPI_CONTEXT_STARTING_POSITION: self.get_data('data.current_tab'),
+                constants.XAPI_CONTEXT_ENDING_POSITION: self.get_data('data.target_tab'),
             })
         elif event_name == 'edx.ui.lms.sequence.next_selected':
             extensions = Extensions({
+                constants.XAPI_CONTEXT_STARTING_POSITION: self.get_data('data.current_tab'),
                 constants.XAPI_CONTEXT_ENDING_POSITION: 'next unit',
             })
         else:
             extensions = Extensions({
+                constants.XAPI_CONTEXT_STARTING_POSITION: self.get_data('data.current_tab'),
                 constants.XAPI_CONTEXT_ENDING_POSITION: 'previous unit',
             })
 
         context = Context(
-            registration=get_anonymous_user_id(
-                self.extract_username_or_userid()
-            ),
             contextActivities=self.get_context_activities()
         )
         context.extensions = extensions
         return context
-
-    def get_context_activities(self):
-        """
-        Get context activities for xAPI transformed event.
-
-        Returns:
-            `ContextActivities`
-        """
-        parent_activities = [
-            Activity(
-                id=self.get_data('data.id'),
-                object_type=constants.XAPI_ACTIVITY_MODULE
-            ),
-        ]
-        return ContextActivities(
-            parent=ActivityList(parent_activities),
-        )
